@@ -32,7 +32,6 @@ orange = "orange"
 otkryt = "otkryt"
 otmenen = "otmenen"
 red = "red"
-resource_none = "none"
 notDefined = "Не определен"
 restarted = "restarted"
 route_made = "route_made"
@@ -43,6 +42,7 @@ started_another = "started_another"
 stoped = "stoped"
 transferred = "transferred"
 unknown = "unknown"
+undefined = "undefined"
 update = "update"
 value_odd = "value_odd"
 zakryt = "zakryt"
