@@ -1,17 +1,38 @@
 import logging
 
-from django.db.models import Model, BooleanField, BigAutoField, DateTimeField, Transform, CharField, TextField
+from django.contrib.postgres.fields import ArrayField
+from django.db.models import Model, BooleanField, BigAutoField, DateTimeField, Transform, CharField, TextField, BigIntegerField
 from django.utils import timezone
 from transliterate import translit
 from transliterate.exceptions import LanguageDetectionError
 
-from isc_common import setAttr
+from isc_common import setAttr, delAttr
 from isc_common.managers.common_manager import CommonManager, CommonQuerySet
 
 logger = logging.getLogger(__name__)
 
 
+class Model_withOldId(Model):
+    old_id = BigIntegerField(db_index=True, null=True, blank=True, unique=True)
+
+    class Meta:
+        abstract = True
+
+
+class Model_withOldIds(Model):
+    old_ids = ArrayField(BigIntegerField(), null=True, blank=True, unique=True)
+
+    class Meta:
+        abstract = True
+
+
 class AuditQuerySet(CommonQuerySet):
+    def getOptional(self, *args, **kwargs):
+        try:
+            return self.get(*args, **kwargs)
+        except self.model.DoesNotExist:
+            return None
+
     def _check_ed_izm_qty(self, **kwargs):
         if kwargs.get('ed_izm') is not None and kwargs.get('qty') is None or kwargs.get('ed_izm') is None and kwargs.get('qty') is not None:
             raise Exception(f'Единица измерения не может быть указана без количества')
@@ -58,11 +79,6 @@ class AuditQuerySet(CommonQuerySet):
             setAttr(kwargs, 'lastmodified', timezone.now())
         return super().update(**kwargs)
 
-    def getOptional(self, *args, **kwargs):
-        try:
-            return self.get(*args, **kwargs)
-        except self.model.DoesNotExist:
-            return None
 
 class AuditManager(CommonManager):
     def __init__(self, *args, **kwargs):
@@ -89,6 +105,24 @@ class AuditManager(CommonManager):
         except self.model.DoesNotExist:
             return None
 
+    def getOr(self, *args, **kwargs):
+        alternative = kwargs.get('alternative')
+        try:
+            delAttr(kwargs, 'alternative')
+            return self.get(*args, **kwargs)
+        except self.model.DoesNotExist:
+            if not callable(alternative):
+                raise Exception('alternative must be callable')
+            return alternative()
+
+
+class Manager(CommonManager):
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+
+    def get_queryset(self):
+        return AuditQuerySet(model=self.model)
+
 
 class AuditModel(Model):
     id = BigAutoField(primary_key=True, verbose_name="Идентификатор")
@@ -103,11 +137,13 @@ class AuditModel(Model):
         return uncapitalize(str)
 
     @classmethod
-    def translit(cls, str):
+    def translit(cls, value):
+        if isinstance(value, int):
+            return str(value)
         try:
-            return cls.uncapitalize(translit(str, reversed=True).replace("'", '').replace(' ', '_').replace('.', '_'))
+            return cls.uncapitalize(translit(value, reversed=True).replace("'", '').replace(' ', '_').replace('.', '_'))
         except LanguageDetectionError:
-            return cls.uncapitalize(str.replace("'", '').replace(' ', '_').replace('.', '_'))
+            return cls.uncapitalize(value.replace("'", '').replace(' ', '_').replace('.', '_'))
 
     @classmethod
     def dbl_qutes_str(cls, str):
@@ -160,3 +196,12 @@ class Trim_Value(Transform):
 
 CharField.register_lookup(Trim_Value)
 TextField.register_lookup(Trim_Value)
+
+
+class Upper_Value(Transform):
+    lookup_name = 'upper'
+    function = 'upper'
+
+
+CharField.register_lookup(Upper_Value)
+TextField.register_lookup(Upper_Value)
